package LCFG::Element;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

use LCFG::Metadata;

#require Exporter;
#require AutoLoader;

#@ISA = qw(Exporter AutoLoader);
# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.
#@EXPORT = qw();

$VERSION = '1.0.10';


# Preloaded methods go here.

sub new {
  my $proto = shift;
  my $class = ref($proto) || $proto;
  my $self = {};
  bless($self,$class);

  if ($self->_initialize(@_)) {
    return $self;
  } else {
    undef $self;
    return undef;
  }
}


sub _initialize {
  my $self=shift;
  
  $self->{ELEMENT} = shift;
  if (@_) {
    $self->{METADATA} = shift;
  } else {
    $self->{METADATA} = undef;
  }
  return 1;
}

#
# Core API extensions
#


sub getType {
  my $self=shift;

  return $self->{METADATA}->getType();
}


sub isResource {
  my $self=shift;

  return ($self->getType() eq 'resource') ? 1:0 ;
}

sub isProperty {
  my $self=shift;

  return $self->isResource() ? 0:1;
}




1;
__END__


=head1 NAME

LCFG::Element - An LCFG node profile element

=head1 SYNOPSIS

=head1 DESCRIPTION

An object representing a node profile element. This object is never
instantiated except as a resource or property element (objects which
extend this one). See L<LCFG::Resource> and L<LCFG::Property>.


Core API methods: new()
Core API extensions: isResource(), isProperty(), getType()

=head1 AUTHOR

Original Author: Tim Colles, timc@dai.ed.ac.uk

Adapted to rdxprof and LCFG::StructResources, and core API extensions:
German Cancio <German.Cancio@cern.ch>



=head1 SEE ALSO

LCFG::Config, LCFG::StructResources

=cut
