package LCFG::Metadata;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

#require Exporter;
#require AutoLoader;

#@ISA = qw(Exporter AutoLoader);
# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.
#@EXPORT = qw();
$VERSION = '1.0.10';


# Preloaded methods go here.

sub new {
  my $proto = shift;
  my $class = ref($proto) || $proto;
  my $self  = {};
  bless($self,$class);

  my $el=shift;

  $self->{CONTEXT} = (defined $el->{'CONTEXT'}) ? $el->{'CONTEXT'} : undef;
  $self->{NAME} = (defined $el->{'NAME'}) ? $el->{'NAME'} : undef;
  $self->{TYPE} = (defined $el->{'TYPE'}) ? $el->{'TYPE'} : undef;
  $self->{DERIVATION} = (defined $el->{'DERIVE'}) ? $el->{'DERIVE'} : undef;

  $self->{TEMPLATE} = undef; # Temporary for old LCFG support

  $self->{ACCESS} = undef; # not supported
  $self->{ENCODING} = undef;
  $self->{DIGEST} = undef;

  return $self;
}

sub getTemplate {
  my $self = shift;
  return $self->{TEMPLATE};
}

sub getContext {
  my $self = shift;
  return $self->{CONTEXT};
}

sub getName {
  my $self = shift;
  return $self->{NAME};
}

sub getType {
  my $self = shift;
  return $self->{TYPE};
}

sub getAccess {
  my $self = shift;
  return $self->{ACCESS};
}

sub getEncoding {
  my $self = shift;
  return $self->{ENCODING};
}

sub getDerivation {
  my $self = shift;
  return $self->{DERIVATION};
}

# Autoload methods go after =cut, and are processed by the autosplit program.

1;
__END__
# Below is the stub of documentation for your module. You better edit it!

=head1 NAME

LCFG::Metadata - An LCFG node profile element metadata

=head1 SYNOPSIS

 $stringvalue = $metadata->getTemplate();
 $stringvalue = $metadata->getContext();
 $stringvalue = $metadata->getName();
 $stringvalue = $metadata->getType();
 $stringvalue = $metadata->getAccess();
 $stringvalue = $metadata->getEncoding();
 $stringvalue = $metadata->getDerivation();

=head1 DESCRIPTION

Provides an API to retrieve the metadata values of a node profile element
(property or resource). A metadata object is retrieved through a method
of the configuration API (see L<LCFG::Config>).

=head2 METHODS

=over 4

=item getTemplate(), getContext(), getName(), getType(), getAccess(),
 getEncoding(), getDerivation()

(Only getContext(), getName(), getType(), getDerivation() are supported in this version)

All return the given attribute of the element as a string.

=head1 EXAMPLES

 use LCFG::CacheManager;
 use LCFG::Path;

 # create a connection to a cache and a configuration 
 $cache = LCFG::CacheManager->new();
 $config = $cache->getUnLockedConfig();

 # create a path object to a property element
 $path = LCFG::Path->new('/test/fubar');

 # get the metadata of the property element corresponding to the path
 $metadata = $config->getMetadata($path);

 # display some of the attribute values
 print "DERIVATION=".$metadata->getDerivation()."\n";
 print "CONTEXT=".$metadata->getContext()."\n";

=head1 AUTHOR

Original Author: Tim Colles, timc@dai.ed.ac.uk

Adapted to rdxprof and LCFG::StructResources: German Cancio <German.Cancio@cern.ch>


=head1 SEE ALSO

  LCFG::Config, LCFG::StructResources

=cut

