package LCFG::Resource;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

use LCFG::Element;

#require Exporter;
#require AutoLoader;

#@ISA = qw(Exporter AutoLoader LCFG::Element);
@ISA=qw(LCFG::Element);

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.
#@EXPORT = qw();
$VERSION = '1.0.10';

sub new {
  my $proto = shift;
  my $class = ref($proto) || $proto;
  my $self = {};
  bless($self,$class);

  if ($self->_initialize(@_)) {
    return $self;
  } else {
    undef $self;
    return undef;
  }
}


sub _initialize {
  my $self=shift;

  unless ($self->SUPER::_initialize(@_)) {
    return undef;
  }

# ?????????????
#  if (@_) { 
# Elements must be returned in the same order as in the XML
#    @{$self->{ELEMENTS}} = reverse(split /\x00/,shift);
#    $self->{INDEX} = @{$self->{ELEMENTS}};
#  } else {
  
  $self->reset();

  return 1;
}




sub isNextElement {
  my $self = shift;

  return (scalar @{$self->{INDEX}}) ? 1 : 0 ;
}

sub getNextElement {
  my $self = shift;

  unless (scalar @{$self->{INDEX}}) {
    warn "No Such Element Exception";
    return undef;
  }
  else {
    return shift @{$self->{INDEX}};
    # note: this returns the name of the element, not the element itself! (?)
  }
}

sub reset {
  my $self = shift;
  my @e_list=(); # assume no elements
  if (defined $self->{ELEMENT}->{'E_LIST'}) {
    @e_list=@{$self->{ELEMENT}->{'E_LIST'}};
  }
  $self->{'INDEX'}=\@e_list;
  return 1;
}


1;
__END__

=head1 NAME

LCFG::Resource - An LCFG node profile resource element

=head1 SYNOPSIS

 $boolean = $resource->isNextElement();
 $elementname = $resource->getNextElement();
 $resource->reset();

=head1 DESCRIPTION

LCFG::Resource extends L<LCFG::Element>.

Provides an API to step through each element of a node profile resource
element. The resource object must already have been retrieved via the
configuration API.

=head2 METHODS

=over 4

=item isNextElement()

Returns true if the iteration has more elements, otherwise returns false.
So, returns true if getNextElement() would return an element instead of throwing
an exception.

=item getNextElement()

Returns the next element in the iteration.

=item reset()

Resets the iteration to the start so that it can be reprocessed.

=head1 EXCEPTIONS

=item * NO SUCH ELEMENT

Raised if the getNextElement() call is made and there are no further elements
to be returned in the iteration.

=head1 EXAMPLES

 use LCFG::CacheManager;
 use LCFG::Path;

 # create a connection to a cache and a configuration 
 $cache = LCFG::CacheManager->new();
 $config = $cache->getUnLockedConfig();

 # create a path object to a resource element
 $path = LCFG::Path->new('/test');

 # get the resource element corresponding to the path
 $resource = $config->getElement($path);

 # iterate through each element in the resource and display its name
 while ($resource->isNextElement()) {
  print $resource->getNextElement()."\n";
 }

=head1 AUTHOR

Original Author: Tim Colles, timc@dai.ed.ac.uk

Adapted to rdxprof and LCFG::StructResources: German Cancio <German.Cancio@cern.ch>



=head1 SEE ALSO

LCFG::Config, LCFG::StructResources


=cut
